==> sinosun-ui-0.1.9.tgz: package/es/support/native/SSPayApi.js <==
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import { callHandler } from "./JSBridge.js";
//支付审批密码器操作类

var SSPayApi = function () {
    function SSPayApi() {
        _classCallCheck(this, SSPayApi);
    }

    _createClass(SSPayApi, [{
        key: 'calculatePassword',

        //描述：计算支付密码
        //场景：票据计算密码
        //对应SnJSBridge接口：CalculatePassword
        //@param Object
        value: function calculatePassword(signData) {
            return callHandler('CalculatePasswordFunction', signData);
        }
        //描述：检测密码器是否插入
        //场景：连接密码器使用
        //对应SnJSBridge接口：TPayGetDssStatusFunction
        //@param Object 
        //return “0” 密码器已经插入    “-1” 密码器未插入

    }, {
        key: 'getDssStatus',
        value: function getDssStatus() {
            return callHandler('TPayGetDssStatusFunction', '');
        }
        //描述：初始化密码器
        //场景：连接密码器使用
        //对应SnJSBridge接口：ConnectDssBb
        //return mCode

    }, {
        key: 'initDss',
        value: function initDss(dev) {
            return callHandler('ConnectDssBbFunction', dev);
        }
        //描述：登录密码器
        //场景：离线密码器使用
        //对应SnJSBridge接口：LoginDss
        //@param Object

    }, {
        key: 'loginDss',
        value: function loginDss(codeUserData) {
            return callHandler('LoginDssFunction', codeUserData);
        }
        //描述：验证pin码
        //场景：线上业务使用，如转账等
        //对应SnJSBridge接口：LoginCA

    }, {
        key: 'loginCA',
        value: function loginCA() {
            return callHandler('TPayCheckPinFunction', '');
        }
        //描述：修改密码器口令
        //对应SnJSBridge接口：ModifyDssPswFunction
        //@param Object

    }, {
        key: 'modifyDssPsw',
        value: function modifyDssPsw(dssPswData) {
            return callHandler('ModifyDssPswFunction', dssPswData);
        }
        //描述：获取密码器付方账号列表
        //场景：离线密码器、同步账号使用
        //对应SnJSBridge接口：GetDssAccountList

    }, {
        key: 'getDssAccountList',
        value: function getDssAccountList() {
            return callHandler('GetDssAccountListFunction', '');
        }
        //描述：添加密码器持有人
        //场景：离线密码器使用
        //对应SnJSBridge接口：SetDssUserFun
        //@param Object

    }, {
        key: 'addDssUser',
        value: function addDssUser(setUserData) {
            return callHandler('SetDssUserFunction', setUserData);
        }
        //描述：用于转账验证服务器签名，并且生成签名接口
        //场景：支付时签名、验签套装接口
        //对应SnJSBridge接口：TPayVerifyAndXmlSignFunction

    }, {
        key: 'signAndCheck',
        value: function signAndCheck(data) {
            return callHandler('TPayVerifyAndXmlSignFunction', data);
        }
    }]);

    return SSPayApi;
}();

export default new SSPayApi();

==> sinosun-ui-0.3.1.tgz: package/es/support/native/SSPayApi.js <==
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import { callHandler } from "./JSBridge.js";
//支付审批密码器操作类

var SSPayApi = function () {
    function SSPayApi() {
        _classCallCheck(this, SSPayApi);
    }

    _createClass(SSPayApi, null, [{
        key: 'calculatePassword',

        //描述：计算支付密码
        //场景：票据计算密码
        //对应SnJSBridge接口：CalculatePassword
        //@param Object
        value: function calculatePassword(signData) {
            return callHandler('CalculatePasswordFunction', signData);
        }
        //描述：检测密码器是否插入
        //场景：连接密码器使用
        //对应SnJSBridge接口：TPayGetDssStatusFunction
        //@param Object 
        //return “0” 密码器已经插入    “-1” 密码器未插入

    }, {
        key: 'getDssStatus',
        value: function getDssStatus() {
            return callHandler('TPayGetDssStatusFunction', '');
        }
        //描述：初始化密码器
        //场景：连接密码器使用
        //对应SnJSBridge接口：ConnectDssBb
        //return mCode

    }, {
        key: 'initDss',
        value: function initDss(dev) {
            return callHandler('ConnectDssBbFunction', dev);
        }
        //描述：登录密码器
        //场景：离线密码器使用
        //对应SnJSBridge接口：LoginDss
        //@param Object

    }, {
        key: 'loginDss',
        value: function loginDss(codeUserData) {
            return callHandler('LoginDssFunction', codeUserData);
        }
        //描述：验证pin码
        //场景：线上业务使用，如转账等
        //对应SnJSBridge接口：LoginCA

    }, {
        key: 'loginCA',
        value: function loginCA() {
            return callHandler('TPayCheckPinFunction', '');
        }
        //描述：修改密码器口令
        //对应SnJSBridge接口：ModifyDssPswFunction
        //@param Object

    }, {
        key: 'modifyDssPsw',
        value: function modifyDssPsw(dssPswData) {
            return callHandler('ModifyDssPswFunction', dssPswData);
        }
        //描述：获取密码器付方账号列表
        //场景：离线密码器、同步账号使用
        //对应SnJSBridge接口：GetDssAccountList

    }, {
        key: 'getDssAccountList',
        value: function getDssAccountList() {
            return callHandler('GetDssAccountListFunction', '');
        }
        //描述：添加密码器持有人
        //场景：离线密码器使用
        //对应SnJSBridge接口：SetDssUserFun
        //@param Object

    }, {
        key: 'addDssUser',
        value: function addDssUser(setUserData) {
            return callHandler('SetDssUserFunction', setUserData);
        }
        //描述：用于转账验证服务器签名，并且生成签名接口
        //场景：支付时签名、验签套装接口
        //对应SnJSBridge接口：TPayVerifyAndXmlSignFunction

    }, {
        key: 'signAndCheck',
        value: function signAndCheck(data) {
            return callHandler('TPayVerifyAndXmlSignFunction', data);
        }
    }]);

    return SSPayApi;
}();

export default SSPayApi;
